@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Aruba
   module Matchers
     module Base
@@ -10,7 +12,7 @@ module Aruba
         def indent_multiline_message(message)
           message = message.sub(/\n+\z/, '')
           message.lines.map do |line|
-            /\S/.match?(line) ? '   ' + line : line
+            /\S/.match?(line) ? "   #{line}" : line
           end.join
         end
       end
